@@ -301,9 +301,7 @@ tdestyle_baghira_config::tdestyle_baghira_config(TQWidget *parent, const char *n
    TQHBoxLayout *rwlh = new TQHBoxLayout(rulesWidget);
    applist = new TDEListView(rulesWidget);
    applist->setFullWidth(true);
-#if KDE_IS_VERSION(3,3,91)
    applist->setShadeSortColumn(false);
-#endif
    applist->setAllColumnsShowFocus( true );
    applist->setSelectionMode(TQListView::Single);
    applist->addColumn ( i18n("Name") );
@@ -338,13 +336,13 @@ tdestyle_baghira_config::tdestyle_baghira_config(TQWidget *parent, const char *n
    rwlv->addStretch();
    dialog_->tabWidget->addTab( rulesWidget, TQString("Rules") );
    appsetter = new AppSetter(this);
-   connect(btnNew, SIGNAL(clicked()), appsetter, SLOT(show()));
-   connect(btnEdit, SIGNAL(clicked()), this, SLOT(editApp()));
-   connect(this, SIGNAL(editApp(TQString, TQString)), appsetter, SLOT(show(TQString, TQString)));
-   connect(btnDel, SIGNAL(clicked()), this, SLOT(removeApp()));
-   connect(btnDet, SIGNAL(clicked()), this, SLOT(selectWindow()));
-   connect(appsetter, SIGNAL(addApp(TQString, TQString)), this, SLOT(addApp(TQString, TQString)));
-   connect(appsetter, SIGNAL(removeApp(TQString)), this, SLOT(removeApp(TQString)));
+   connect(btnNew, TQ_SIGNAL(clicked()), appsetter, TQ_SLOT(show()));
+   connect(btnEdit, TQ_SIGNAL(clicked()), this, TQ_SLOT(editApp()));
+   connect(this, TQ_SIGNAL(editApp(TQString, TQString)), appsetter, TQ_SLOT(show(TQString, TQString)));
+   connect(btnDel, TQ_SIGNAL(clicked()), this, TQ_SLOT(removeApp()));
+   connect(btnDet, TQ_SIGNAL(clicked()), this, TQ_SLOT(selectWindow()));
+   connect(appsetter, TQ_SIGNAL(addApp(TQString, TQString)), this, TQ_SLOT(addApp(TQString, TQString)));
+   connect(appsetter, TQ_SIGNAL(removeApp(TQString)), this, TQ_SLOT(removeApp(TQString)));
    // preview stuff
    baseImage = uic_findImage("button-base");
 
@@ -360,7 +358,7 @@ tdestyle_baghira_config::tdestyle_baghira_config(TQWidget *parent, const char *n
    crNotes[1] = "<qt>© \"Design\" 2001-2005 by Apple inc.<br>http://www.apple.com";
    crNotes[2] = "<qt>© \"Milk\" 2002-2005 by Max Rudberg<br>http://www.maxthemes.com</qt>";
    timer = new TQTimer();
-   connect( timer, SIGNAL(timeout()), this, SLOT(updateCR()) );
+   connect( timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(updateCR()) );
    TQString tmpString(TQT_BUILD_KEY);
    about_->systemLabel->setText(tmpString.section(' ',1,1));
    about_->cpuLabel->setText(tmpString.section(' ',0,0));
@@ -368,93 +366,93 @@ tdestyle_baghira_config::tdestyle_baghira_config(TQWidget *parent, const char *n
 
    // connections
    // buttons
-   connect(dialog_->buttonHelp, SIGNAL(clicked()), help_, SLOT(exec()));
-   connect(dialog_->buttonAbout, SIGNAL(clicked()), this, SLOT(showAbout()));
-   connect(about_->buttonInfo, SIGNAL(clicked()), this, SLOT(openHtml1()));
-   connect(about_->buttonDownload, SIGNAL(clicked()), this, SLOT(openHtml2()));
-   connect(help_->startBAB, SIGNAL(clicked()), this, SLOT(startBab()));
-   connect(dialog_->startKRuler, SIGNAL(clicked()), this, SLOT(startKRuler()));
-   connect(dialog_->buttonLoad, SIGNAL(clicked()), this, SLOT(buttonLoadAction()));
-   connect(dialog_->buttonSaveAs, SIGNAL(clicked()), this, SLOT(buttonSaveAsAction()));
-   connect(dialog_->colorPresets, SIGNAL(activated(int)), this, SLOT(setPresetColor(int)));
+   connect(dialog_->buttonHelp, TQ_SIGNAL(clicked()), help_, TQ_SLOT(exec()));
+   connect(dialog_->buttonAbout, TQ_SIGNAL(clicked()), this, TQ_SLOT(showAbout()));
+   connect(about_->buttonInfo, TQ_SIGNAL(clicked()), this, TQ_SLOT(openHtml1()));
+   connect(about_->buttonDownload, TQ_SIGNAL(clicked()), this, TQ_SLOT(openHtml2()));
+   connect(help_->startBAB, TQ_SIGNAL(clicked()), this, TQ_SLOT(startBab()));
+   connect(dialog_->startKRuler, TQ_SIGNAL(clicked()), this, TQ_SLOT(startKRuler()));
+   connect(dialog_->buttonLoad, TQ_SIGNAL(clicked()), this, TQ_SLOT(buttonLoadAction()));
+   connect(dialog_->buttonSaveAs, TQ_SIGNAL(clicked()), this, TQ_SLOT(buttonSaveAsAction()));
+   connect(dialog_->colorPresets, TQ_SIGNAL(activated(int)), this, TQ_SLOT(setPresetColor(int)));
 
    // changes
-   connect(dialog_->defaultStyle, SIGNAL(activated(int)), this, SLOT(configChanged()));
-   connect(dialog_->buttonStyle, SIGNAL(activated(int)), this, SLOT(handleButtonStyles(int)));
-   connect(dialog_->toolbuttonStyle, SIGNAL(activated(int)), this, SLOT(handleButtonStyles(int)));
-   connect(dialog_->animateButtons, SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->stippleBackground, SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->bevelHighlights, SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->stippleContrast, SIGNAL(valueChanged (int)), this, SLOT(configChanged()));
-   connect(dialog_->shadowGroups,  SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->shadowIntensity, SIGNAL(valueChanged (int)), this, SLOT(configChanged()));
-   connect(dialog_->centerTabs,  SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->colorMode, SIGNAL(activated(int)), this, SLOT(configChanged()));
-   connect(dialog_->inactiveColorType, SIGNAL(activated(int)), this, SLOT(configChanged()));
-   connect(dialog_->animateSlider,  SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->shadowSlider,  SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->squeezeSlider,  SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->unhoveredToolButtons,  SIGNAL(activated(int)), this, SLOT(configChanged()));
-   connect(dialog_->aquaTabs,  SIGNAL(activated(int)), this, SLOT(configChanged()));
-   connect(dialog_->brushedTabs,  SIGNAL(activated(int)), this, SLOT(configChanged()));
-   connect(dialog_->drawTreeLines,  SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->useCustomExpanderColor,  SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->treeLineMode, SIGNAL(activated(int)), this, SLOT(configChanged()));
-   connect(dialog_->expanderMode, SIGNAL(activated(int)), this, SLOT(configChanged()));
-   connect(dialog_->useCustomExpanderColor,  SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->useRectLVH,  SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->removeKickerBevel,  SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->replaceMenubar,  SIGNAL(toggled(bool)), this, SLOT(menuToggled(bool)));
-   connect(dialog_->roundTasks,  SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->showProgressValue,  SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->progressType, SIGNAL(activated(int)), this, SLOT(configChanged()));
-   connect(dialog_->menuBackground, SIGNAL(activated(int)), this, SLOT(configChanged()));
-   connect(dialog_->menuOpacity, SIGNAL(valueChanged (int)), this, SLOT(configChanged()));
-   connect(dialog_->shadowMenuText, SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->menuColorMode, SIGNAL(activated(int)), this, SLOT(configChanged()));
-   connect(dialog_->useCustomColors, SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->drawMenuStripe, SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
-   connect(dialog_->glossyMenus, SIGNAL(stateChanged(int)), this, SLOT(configChanged()));
+   connect(dialog_->defaultStyle, TQ_SIGNAL(activated(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->buttonStyle, TQ_SIGNAL(activated(int)), this, TQ_SLOT(handleButtonStyles(int)));
+   connect(dialog_->toolbuttonStyle, TQ_SIGNAL(activated(int)), this, TQ_SLOT(handleButtonStyles(int)));
+   connect(dialog_->animateButtons, TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->stippleBackground, TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->bevelHighlights, TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->stippleContrast, TQ_SIGNAL(valueChanged (int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->shadowGroups,  TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->shadowIntensity, TQ_SIGNAL(valueChanged (int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->centerTabs,  TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->colorMode, TQ_SIGNAL(activated(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->inactiveColorType, TQ_SIGNAL(activated(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->animateSlider,  TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->shadowSlider,  TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->squeezeSlider,  TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->unhoveredToolButtons,  TQ_SIGNAL(activated(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->aquaTabs,  TQ_SIGNAL(activated(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->brushedTabs,  TQ_SIGNAL(activated(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->drawTreeLines,  TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->useCustomExpanderColor,  TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->treeLineMode, TQ_SIGNAL(activated(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->expanderMode, TQ_SIGNAL(activated(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->useCustomExpanderColor,  TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->useRectLVH,  TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->removeKickerBevel,  TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->replaceMenubar,  TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(menuToggled(bool)));
+   connect(dialog_->roundTasks,  TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->showProgressValue,  TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->progressType, TQ_SIGNAL(activated(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->menuBackground, TQ_SIGNAL(activated(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->menuOpacity, TQ_SIGNAL(valueChanged (int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->shadowMenuText, TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->menuColorMode, TQ_SIGNAL(activated(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->useCustomColors, TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->drawMenuStripe, TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->glossyMenus, TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(configChanged()));
 
-   connect(dialog_->customInactiveColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-connect(dialog_->toolbuttonHighColor, SIGNAL(changed(const TQColor &)), this, SLOT(changeTooluttonHighlightColor(const TQColor &)));
-   connect(dialog_->treeLineColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->customExpanderColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->menuTextColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->menuTextColorHigh, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->menuColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->menuColorHigh, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->menuColor2, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->radioOffColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->radioOnColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->checkOffColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->checkOnColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->sliderColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->hoverSliderColorColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->pressedSliderColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->inactiveTabColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->activeTabColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
-   connect(dialog_->menuStripeColor, SIGNAL(changed(const TQColor &)), this, SLOT(configChanged()));
+   connect(dialog_->customInactiveColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+connect(dialog_->toolbuttonHighColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(changeTooluttonHighlightColor(const TQColor &)));
+   connect(dialog_->treeLineColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->customExpanderColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->menuTextColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->menuTextColorHigh, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->menuColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->menuColorHigh, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->menuColor2, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->radioOffColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->radioOnColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->checkOffColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->checkOnColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->sliderColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->hoverSliderColorColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->pressedSliderColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->inactiveTabColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->activeTabColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
+   connect(dialog_->menuStripeColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(configChanged()));
 
-   connect(dialog_->sliderButtonRed, SIGNAL(valueChanged (int)), this, SLOT(sliderButtonRedChanged(int)));
-   connect(dialog_->sliderButtonGreen, SIGNAL(valueChanged (int)), this, SLOT(sliderButtonGreenChanged(int)));
-   connect(dialog_->sliderButtonBlue, SIGNAL(valueChanged (int)), this, SLOT(sliderButtonBlueChanged(int)));
+   connect(dialog_->sliderButtonRed, TQ_SIGNAL(valueChanged (int)), this, TQ_SLOT(sliderButtonRedChanged(int)));
+   connect(dialog_->sliderButtonGreen, TQ_SIGNAL(valueChanged (int)), this, TQ_SLOT(sliderButtonGreenChanged(int)));
+   connect(dialog_->sliderButtonBlue, TQ_SIGNAL(valueChanged (int)), this, TQ_SLOT(sliderButtonBlueChanged(int)));
 
-   connect(dialog_->sliderBrushRed, SIGNAL(valueChanged (int)), this, SLOT(sliderBrushRedChanged(int)));
-   connect(dialog_->sliderBrushGreen, SIGNAL(valueChanged (int)), this, SLOT(sliderBrushGreenChanged(int)));
-   connect(dialog_->sliderBrushBlue, SIGNAL(valueChanged (int)), this, SLOT(sliderBrushBlueChanged(int)));
+   connect(dialog_->sliderBrushRed, TQ_SIGNAL(valueChanged (int)), this, TQ_SLOT(sliderBrushRedChanged(int)));
+   connect(dialog_->sliderBrushGreen, TQ_SIGNAL(valueChanged (int)), this, TQ_SLOT(sliderBrushGreenChanged(int)));
+   connect(dialog_->sliderBrushBlue, TQ_SIGNAL(valueChanged (int)), this, TQ_SLOT(sliderBrushBlueChanged(int)));
 
    // GUI
-   connect (dialog_->defaultStyle, SIGNAL(activated(int)), this, SLOT(setDesign(int)));
-   connect (dialog_->inactiveColorType, SIGNAL(activated(int)), this, SLOT(enableInButtonColor(int)));
-   connect (dialog_->drawTreeLines, SIGNAL(toggled(bool)), dialog_->treeLineMode, SLOT(setEnabled(bool)));
-   connect (dialog_->drawTreeLines, SIGNAL(toggled(bool)), dialog_->treeLineColor, SLOT(setEnabled(bool)));
-   connect (dialog_->useCustomExpanderColor, SIGNAL(toggled(bool)), dialog_->customExpanderColor, SLOT(setEnabled(bool)));
-   connect (dialog_->menuColorMode, SIGNAL(activated(int)), this, SLOT(enableMenuColorStuff(int)));
-   connect (dialog_->menuBackground, SIGNAL(activated(int)), this, SLOT(enableMenuColorStuff(int)));
-   connect (dialog_->drawMenuStripe, SIGNAL(toggled(bool)), dialog_->menuStripeColor, SLOT(setEnabled(bool)));
-//     connect (dialog_->tintBrush, SIGNAL(toggled(bool)), dialog_->brushBox, SLOT(setEnabled(bool)));
-   connect (dialog_->useCustomColors, SIGNAL(toggled(bool)), dialog_->colorFrame, SLOT(setEnabled(bool)));
+   connect (dialog_->defaultStyle, TQ_SIGNAL(activated(int)), this, TQ_SLOT(setDesign(int)));
+   connect (dialog_->inactiveColorType, TQ_SIGNAL(activated(int)), this, TQ_SLOT(enableInButtonColor(int)));
+   connect (dialog_->drawTreeLines, TQ_SIGNAL(toggled(bool)), dialog_->treeLineMode, TQ_SLOT(setEnabled(bool)));
+   connect (dialog_->drawTreeLines, TQ_SIGNAL(toggled(bool)), dialog_->treeLineColor, TQ_SLOT(setEnabled(bool)));
+   connect (dialog_->useCustomExpanderColor, TQ_SIGNAL(toggled(bool)), dialog_->customExpanderColor, TQ_SLOT(setEnabled(bool)));
+   connect (dialog_->menuColorMode, TQ_SIGNAL(activated(int)), this, TQ_SLOT(enableMenuColorStuff(int)));
+   connect (dialog_->menuBackground, TQ_SIGNAL(activated(int)), this, TQ_SLOT(enableMenuColorStuff(int)));
+   connect (dialog_->drawMenuStripe, TQ_SIGNAL(toggled(bool)), dialog_->menuStripeColor, TQ_SLOT(setEnabled(bool)));
+//     connect (dialog_->tintBrush, TQ_SIGNAL(toggled(bool)), dialog_->brushBox, TQ_SLOT(setEnabled(bool)));
+   connect (dialog_->useCustomColors, TQ_SIGNAL(toggled(bool)), dialog_->colorFrame, TQ_SLOT(setEnabled(bool)));
 
    // load settings
    load();
@@ -1065,17 +1063,17 @@ AppSetter::AppSetter(TQWidget *parent, const char *name) : TQWidget(parent, name
 
    colorDialog = new ColorDialog(this);
 
-   connect(box, SIGNAL(toggled( bool )), link, SLOT(setDisabled(bool)));
-   connect(box, SIGNAL(toggled( bool )), linkTo, SLOT(setDisabled(bool)));
-   connect(style, SIGNAL(activated( int )), this, SLOT(handler(int)));
-   connect(buttons, SIGNAL(activated( int )), this, SLOT(handleButtonStyles(int)));
-   connect(toolButtons, SIGNAL(activated( int )), this, SLOT(handleButtonStyles(int)));
-   connect(cancel, SIGNAL(clicked()), this, SLOT(reset()));
-   connect(ok, SIGNAL(clicked()), this, SLOT(save()));
-   connect(customColors, SIGNAL(toggled( bool )), buttonColors, SLOT(setEnabled(bool)));
-   connect(buttonColors, SIGNAL(clicked()), colorDialog, SLOT(exec()));
-   connect(colorDialog->buttonOk, SIGNAL(clicked()), this, SLOT(updateColors()));
-   connect(colorDialog->buttonCancel, SIGNAL(clicked()), this, SLOT(resetColorPicker()));
+   connect(box, TQ_SIGNAL(toggled( bool )), link, TQ_SLOT(setDisabled(bool)));
+   connect(box, TQ_SIGNAL(toggled( bool )), linkTo, TQ_SLOT(setDisabled(bool)));
+   connect(style, TQ_SIGNAL(activated( int )), this, TQ_SLOT(handler(int)));
+   connect(buttons, TQ_SIGNAL(activated( int )), this, TQ_SLOT(handleButtonStyles(int)));
+   connect(toolButtons, TQ_SIGNAL(activated( int )), this, TQ_SLOT(handleButtonStyles(int)));
+   connect(cancel, TQ_SIGNAL(clicked()), this, TQ_SLOT(reset()));
+   connect(ok, TQ_SIGNAL(clicked()), this, TQ_SLOT(save()));
+   connect(customColors, TQ_SIGNAL(toggled( bool )), buttonColors, TQ_SLOT(setEnabled(bool)));
+   connect(buttonColors, TQ_SIGNAL(clicked()), colorDialog, TQ_SLOT(exec()));
+   connect(colorDialog->buttonOk, TQ_SIGNAL(clicked()), this, TQ_SLOT(updateColors()));
+   connect(colorDialog->buttonCancel, TQ_SIGNAL(clicked()), this, TQ_SLOT(resetColorPicker()));
    reset();
 }
 
