@@ -189,13 +189,13 @@ void DeMaximizer::setClient(BaghiraClient *client)
 {
    if (client_)
    {
-      TQObject::disconnect ( client_, SIGNAL(hide()), this, SLOT(hide()) );
+      TQObject::disconnect ( client_, TQ_SIGNAL(hide()), this, TQ_SLOT(hide()) );
       client_ = 0L;
    }
    if (client)
    {
       client_ = client;
-      connect ( client_, SIGNAL(hide()), SLOT(hide()) );
+      connect ( client_, TQ_SIGNAL(hide()), TQ_SLOT(hide()) );
       setState(0);
    }
 //     repaint();
@@ -1278,7 +1278,7 @@ void BaghiraButton::enterEvent( TQEvent *e ) {
    if (type_ == CloseButton)
    {
       _blocked = true;
-      TQTimer::singleShot(250,this,SLOT(delayedEnterEvent()));
+      TQTimer::singleShot(250,this,TQ_SLOT(delayedEnterEvent()));
       TQButton::enterEvent( e );
       return;
    }
@@ -1662,8 +1662,8 @@ void BaghiraClient::addButtons( TQBoxLayout *layout, const TQString& s )
 				if ( !button[ MenuButton ] ) {
 					button[ MenuButton ] = new BaghiraButton( this, "menu",
 					                       i18n( "Menu" ), isTool(), MenuButton );
-					connect( button[ MenuButton ], SIGNAL( pressed() ), this,
-					         SLOT( menuButtonPressed() ) );
+					connect( button[ MenuButton ], TQ_SIGNAL( pressed() ), this,
+					         TQ_SLOT( menuButtonPressed() ) );
 					layout->addWidget( button[ MenuButton ] );
                                         buttonAdded = true;
 					excursion = excursion + plusminus * MENUBUTTONWIDTH;
@@ -1680,8 +1680,8 @@ void BaghiraClient::addButtons( TQBoxLayout *layout, const TQString& s )
 					}
 					button[ StickyButton ] = new BaghiraButton( this, "sticky",
 					                         tip, isTool(), StickyButton );
-					connect( button[ StickyButton ], SIGNAL( clicked() ), this,
-					         SLOT( toggleOnAllDesktops() ) );
+					connect( button[ StickyButton ], TQ_SIGNAL( clicked() ), this,
+					         TQ_SLOT( toggleOnAllDesktops() ) );
 					layout->addWidget( button[ StickyButton ] );
                                         buttonAdded = true;
 					excursion = excursion + plusminus * BUTTONSIZE;
@@ -1693,8 +1693,8 @@ void BaghiraClient::addButtons( TQBoxLayout *layout, const TQString& s )
 				if ( ( !button[ HelpButton ] ) && providesContextHelp() ) {
 					button[ HelpButton ] = new BaghiraButton( this, "help",
 					                       i18n( "Help" ), isTool(), HelpButton );
-					connect( button[ HelpButton ], SIGNAL( clicked() ), this,
-					         SLOT( showContextHelp() ) );
+					connect( button[ HelpButton ], TQ_SIGNAL( clicked() ), this,
+					         TQ_SLOT( showContextHelp() ) );
 					layout->addWidget( button[ HelpButton ] );
                                         buttonAdded = true;
 					excursion = excursion + plusminus * BUTTONSIZE;
@@ -1706,8 +1706,8 @@ void BaghiraClient::addButtons( TQBoxLayout *layout, const TQString& s )
 				if ( ( !button[ MinButton ] ) && isMinimizable() ) {
 					button[ MinButton ] = new BaghiraButton( this, "iconify",
 					                      i18n( "Minimize" ), isTool(), MinButton );
-					connect( button[ MinButton ], SIGNAL( clicked() ), this,
-					         SLOT( minimize() ) );
+					connect( button[ MinButton ], TQ_SIGNAL( clicked() ), this,
+					         TQ_SLOT( minimize() ) );
 					layout->addWidget( button[ MinButton ] );
                                         buttonAdded = true;
 					excursion = excursion + plusminus * BUTTONSIZE;
@@ -1724,8 +1724,8 @@ void BaghiraClient::addButtons( TQBoxLayout *layout, const TQString& s )
 					}
 					button[ MaxButton ] = new BaghiraButton( this, "maximize",
 					                      tip, isTool(), MaxButton );
-					connect( button[ MaxButton ], SIGNAL( clicked() ), this,
-					         SLOT( maxButtonPressed() ) );
+					connect( button[ MaxButton ], TQ_SIGNAL( clicked() ), this,
+					         TQ_SLOT( maxButtonPressed() ) );
 					layout->addWidget( button[ MaxButton ] );
                                         buttonAdded = true;
 					excursion = excursion + plusminus * BUTTONSIZE;
@@ -1737,8 +1737,8 @@ void BaghiraClient::addButtons( TQBoxLayout *layout, const TQString& s )
 				if ( ( !button[ CloseButton ] ) && isCloseable() ) {
 					button[ CloseButton ] = new BaghiraButton( this, "close",
 					                        i18n( "Close" ), isTool(), CloseButton );
-					connect( button[ CloseButton ], SIGNAL( clicked() ), this,
-					         SLOT( closeWindow() ) );
+					connect( button[ CloseButton ], TQ_SIGNAL( clicked() ), this,
+					         TQ_SLOT( closeWindow() ) );
 					layout->addWidget( button[ CloseButton ] );
                                         buttonAdded = true;
 					excursion = excursion + plusminus * BUTTONSIZE;
@@ -1756,7 +1756,7 @@ void BaghiraClient::addButtons( TQBoxLayout *layout, const TQString& s )
 				{
                button[AboveBelowButton] = new BaghiraButton(this, "above", i18n("Keep Above/Below Others"), isTool(), AboveBelowButton);
    				button[AboveBelowButton]->setDown( keepAbove() || keepBelow() );
-               connect(button[AboveBelowButton], SIGNAL(clicked()), this, SLOT(aboveBelowButtonPressed()));
+               connect(button[AboveBelowButton], TQ_SIGNAL(clicked()), this, TQ_SLOT(aboveBelowButtonPressed()));
                layout->addWidget(button[AboveBelowButton]);
                buttonAdded = true;
                excursion = excursion + plusminus * BUTTONSIZE;
@@ -1767,7 +1767,7 @@ void BaghiraClient::addButtons( TQBoxLayout *layout, const TQString& s )
 				if ((!button[ShadeButton] && isShadeable())) {
 				button[ShadeButton] = new BaghiraButton(this, "shade", isSetShade() ? tip = i18n("Unshade") : tip = i18n("Shade"), isTool(), ShadeButton);
                                 button[ShadeButton]->setDown( isShade() );
-				connect(button[ShadeButton], SIGNAL(clicked()), this, SLOT(shadeButtonPressed()));
+				connect(button[ShadeButton], TQ_SIGNAL(clicked()), this, TQ_SLOT(shadeButtonPressed()));
 				layout->addWidget(button[ShadeButton]);
                                 buttonAdded = true;
 				excursion = excursion + plusminus * BUTTONSIZE;
@@ -1778,7 +1778,7 @@ void BaghiraClient::addButtons( TQBoxLayout *layout, const TQString& s )
 // 				if ((!button[ShadeButton] && isShadeable())) {
 // 				button[ShadeButton] = new BaghiraButton(this, "shade", isSetShade() ? tip = i18n("Unshade") : tip = i18n("Shade"), isTool(), ShadeButton);
 //                                 button[ShadeButton]->setDown( isShade() );
-// 				connect(button[ShadeButton], SIGNAL(clicked()), this, SLOT(shadeButtonPressed()));
+// 				connect(button[ShadeButton], TQ_SIGNAL(clicked()), this, TQ_SLOT(shadeButtonPressed()));
 // 				layout->addWidget(button[ShadeButton]);
 //                                 buttonAdded = true;
 // 				excursion = excursion + plusminus * BUTTONSIZE;
