@@ -53,96 +53,96 @@ BaghiraConfig::BaghiraConfig(TDEConfig*, TQWidget* parent)
     
     dialog_->show();
     
-    connect(dialog_->ButtonColorConfig, SIGNAL(clicked()), buttonDialog_, SLOT(exec()));
-    connect(buttonDialog_->ok, SIGNAL(clicked()), SIGNAL(changed()));
+    connect(dialog_->ButtonColorConfig, TQ_SIGNAL(clicked()), buttonDialog_, TQ_SLOT(exec()));
+    connect(buttonDialog_->ok, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
             
     // connections
-    connect(dialog_->titlealign, SIGNAL(clicked(int)), SIGNAL(changed()));
-    connect(dialog_->drawComicFrame, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->addAutoSpacing, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->allowEasyClosing, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->ResizeGrip, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->maxResizable, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->fullSpec, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->noModalDeco, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->delAppname, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->defaultMode, SIGNAL(activated(int)),  SIGNAL(changed()));
-    connect(dialog_->minTH, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+    connect(dialog_->titlealign, TQ_SIGNAL(clicked(int)), TQ_SIGNAL(changed()));
+    connect(dialog_->drawComicFrame, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->addAutoSpacing, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->allowEasyClosing, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->ResizeGrip, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->maxResizable, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->fullSpec, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->noModalDeco, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->delAppname, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->defaultMode, TQ_SIGNAL(activated(int)),  TQ_SIGNAL(changed()));
+    connect(dialog_->minTH, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
     
-    connect(dialog_->activeColor1_J, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->activeColor2_J, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->inactiveColor1_J, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->inactiveColor2_J, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->buttonStyle_J, SIGNAL(activated(int)), SIGNAL(changed()));
-    connect(dialog_->shapeUL_J, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->shapeUR_J, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->shapeLL_J, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->shapeLR_J, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->drawIcon_J, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->titleeffect_J, SIGNAL(activated(int)),  SIGNAL(changed()));
-    connect(dialog_->i_titleeffect_J, SIGNAL(activated(int)), SIGNAL(changed()));
-    connect(dialog_->_3DImpact_J, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-    connect(dialog_->LineImpact_J, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-   connect(dialog_->borderSize_J, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+    connect(dialog_->activeColor1_J, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+    connect(dialog_->activeColor2_J, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+    connect(dialog_->inactiveColor1_J, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+    connect(dialog_->inactiveColor2_J, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+    connect(dialog_->buttonStyle_J, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
+    connect(dialog_->shapeUL_J, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->shapeUR_J, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->shapeLL_J, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->shapeLR_J, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->drawIcon_J, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->titleeffect_J, TQ_SIGNAL(activated(int)),  TQ_SIGNAL(changed()));
+    connect(dialog_->i_titleeffect_J, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
+    connect(dialog_->_3DImpact_J, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
+    connect(dialog_->LineImpact_J, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
+   connect(dialog_->borderSize_J, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
             
-    connect(dialog_->activeColor1_P, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->activeColor2_P, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->inactiveColor1_P, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->inactiveColor2_P, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->buttonStyle_P, SIGNAL(activated(int)), SIGNAL(changed()));
-    connect(dialog_->shapeUL_P, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->shapeUR_P, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->shapeLL_P, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->shapeLR_P, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->drawIcon_P, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->titleeffect_P, SIGNAL(activated(int)), SIGNAL(changed()));
-    connect(dialog_->i_titleeffect_P, SIGNAL(activated(int)), SIGNAL(changed()));
-    connect(dialog_->_3DImpact_P, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-    connect(dialog_->LineImpact_P, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-   connect(dialog_->borderSize_P, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+    connect(dialog_->activeColor1_P, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+    connect(dialog_->activeColor2_P, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+    connect(dialog_->inactiveColor1_P, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+    connect(dialog_->inactiveColor2_P, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+    connect(dialog_->buttonStyle_P, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
+    connect(dialog_->shapeUL_P, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->shapeUR_P, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->shapeLL_P, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->shapeLR_P, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->drawIcon_P, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->titleeffect_P, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
+    connect(dialog_->i_titleeffect_P, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
+    connect(dialog_->_3DImpact_P, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
+    connect(dialog_->LineImpact_P, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
+   connect(dialog_->borderSize_P, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
             
-    connect(dialog_->activeColor1_B, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->activeColor2_B, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->inactiveColor1_B, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->inactiveColor2_B, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->buttonStyle_B, SIGNAL(activated(int)), SIGNAL(changed()));
-    connect(dialog_->shapeUL_B, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->shapeUR_B, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->shapeLL_B, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->shapeLR_B, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->drawIcon_B, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->titleeffect_B, SIGNAL(activated(int)),  SIGNAL(changed()));
-    connect(dialog_->i_titleeffect_B, SIGNAL(activated(int)), SIGNAL(changed()));
-    connect(dialog_->_3DImpact_B, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-    connect(dialog_->LineImpact_B, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-   connect(dialog_->borderSize_B, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+    connect(dialog_->activeColor1_B, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+    connect(dialog_->activeColor2_B, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+    connect(dialog_->inactiveColor1_B, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+    connect(dialog_->inactiveColor2_B, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+    connect(dialog_->buttonStyle_B, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
+    connect(dialog_->shapeUL_B, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->shapeUR_B, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->shapeLL_B, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->shapeLR_B, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->drawIcon_B, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(dialog_->titleeffect_B, TQ_SIGNAL(activated(int)),  TQ_SIGNAL(changed()));
+    connect(dialog_->i_titleeffect_B, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
+    connect(dialog_->_3DImpact_B, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
+    connect(dialog_->LineImpact_B, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
+   connect(dialog_->borderSize_B, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
    
-   connect(dialog_->activeColor1_T, SIGNAL(clicked()), SIGNAL(changed()));
-   connect(dialog_->activeColor2_T, SIGNAL(clicked()), SIGNAL(changed()));            
-   connect(dialog_->buttonStyle_T, SIGNAL(activated(int)), SIGNAL(changed()));
-   connect(dialog_->shapeUL_T, SIGNAL(toggled(bool)), SIGNAL(changed()));
-   connect(dialog_->shapeUR_T, SIGNAL(toggled(bool)), SIGNAL(changed()));
-   connect(dialog_->shapeLL_T, SIGNAL(toggled(bool)), SIGNAL(changed()));
-   connect(dialog_->shapeLR_T, SIGNAL(toggled(bool)), SIGNAL(changed()));
-   connect(dialog_->drawIcon_T, SIGNAL(toggled(bool)), SIGNAL(changed()));    
-   connect(dialog_->_3DImpact_T, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-   connect(dialog_->borderSize_T, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+   connect(dialog_->activeColor1_T, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+   connect(dialog_->activeColor2_T, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));            
+   connect(dialog_->buttonStyle_T, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
+   connect(dialog_->shapeUL_T, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+   connect(dialog_->shapeUR_T, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+   connect(dialog_->shapeLL_T, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+   connect(dialog_->shapeLR_T, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+   connect(dialog_->drawIcon_T, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));    
+   connect(dialog_->_3DImpact_T, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
+   connect(dialog_->borderSize_T, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
    
-   connect(dialog_->activeColor1_S, SIGNAL(clicked()), SIGNAL(changed()));
-   connect(dialog_->activeColor2_S, SIGNAL(clicked()), SIGNAL(changed()));
-   connect(dialog_->inactiveColor1_S, SIGNAL(clicked()), SIGNAL(changed()));
-   connect(dialog_->inactiveColor2_S, SIGNAL(clicked()), SIGNAL(changed()));
-   connect(dialog_->buttonStyle_S, SIGNAL(activated(int)), SIGNAL(changed()));
-   connect(dialog_->shapeUL_S, SIGNAL(toggled(bool)), SIGNAL(changed()));
-   connect(dialog_->shapeUR_S, SIGNAL(toggled(bool)), SIGNAL(changed()));
-   connect(dialog_->shapeLL_S, SIGNAL(toggled(bool)), SIGNAL(changed()));
-   connect(dialog_->shapeLR_S, SIGNAL(toggled(bool)), SIGNAL(changed()));
-   connect(dialog_->drawIcon_S, SIGNAL(toggled(bool)), SIGNAL(changed()));
-   connect(dialog_->titleeffect_S, SIGNAL(activated(int)),  SIGNAL(changed()));
-   connect(dialog_->i_titleeffect_S, SIGNAL(activated(int)), SIGNAL(changed()));
-   connect(dialog_->_3DImpact_S, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-   connect(dialog_->LineImpact_S, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-   connect(dialog_->borderSize_S, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+   connect(dialog_->activeColor1_S, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+   connect(dialog_->activeColor2_S, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+   connect(dialog_->inactiveColor1_S, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+   connect(dialog_->inactiveColor2_S, TQ_SIGNAL(clicked()), TQ_SIGNAL(changed()));
+   connect(dialog_->buttonStyle_S, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
+   connect(dialog_->shapeUL_S, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+   connect(dialog_->shapeUR_S, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+   connect(dialog_->shapeLL_S, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+   connect(dialog_->shapeLR_S, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+   connect(dialog_->drawIcon_S, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+   connect(dialog_->titleeffect_S, TQ_SIGNAL(activated(int)),  TQ_SIGNAL(changed()));
+   connect(dialog_->i_titleeffect_S, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
+   connect(dialog_->_3DImpact_S, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
+   connect(dialog_->LineImpact_S, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
+   connect(dialog_->borderSize_S, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
 //     config_->endGroup();
 
 }
@@ -596,34 +596,34 @@ ButtonColors::ButtonColors(TQWidget *parent, const char * name) : TQDialog(paren
     resize( TQSize(485, 177).expandedTo(minimumSizeHint()) );
     clearWState( WState_Polished );
     
-    connect(presets_,SIGNAL(activated(int)), this, SLOT(setColorGroup(int)));
-    connect(ok, SIGNAL(clicked()), this, SLOT(setSave()));
-    connect(ok, SIGNAL(clicked()), this, SLOT(close()) );
-    connect(ok, SIGNAL(clicked()), this, SLOT(init()) );
-    connect(cancel, SIGNAL(clicked()), this, SLOT(close()) );
-    connect(cancel, SIGNAL(clicked()), this, SLOT(reset()) );
+    connect(presets_,TQ_SIGNAL(activated(int)), this, TQ_SLOT(setColorGroup(int)));
+    connect(ok, TQ_SIGNAL(clicked()), this, TQ_SLOT(setSave()));
+    connect(ok, TQ_SIGNAL(clicked()), this, TQ_SLOT(close()) );
+    connect(ok, TQ_SIGNAL(clicked()), this, TQ_SLOT(init()) );
+    connect(cancel, TQ_SIGNAL(clicked()), this, TQ_SLOT(close()) );
+    connect(cancel, TQ_SIGNAL(clicked()), this, TQ_SLOT(reset()) );
     
-    connect(inactiveButton, SIGNAL(clicked()), this, SLOT(activateInactive()) );
-    connect(closeButton, SIGNAL(clicked()), this, SLOT(activateClose()) );
-    connect(minButton, SIGNAL(clicked()), this, SLOT(activateMin()) );
-    connect(maxButton, SIGNAL(clicked()), this, SLOT(activateMax()) );
-    connect(menuButton, SIGNAL(clicked()), this, SLOT(activateMenu()) );
-    connect(helpButton, SIGNAL(clicked()), this, SLOT(activateHelp()) );
-    connect(stickyButton, SIGNAL(clicked()), this, SLOT(activateSticky()) );
-    connect(aboveButton, SIGNAL(clicked()), this, SLOT(activateAbove()) );
-    connect(behindButton, SIGNAL(clicked()), this, SLOT(activateBehind()) );
-    connect(shadeButton, SIGNAL(clicked()), this, SLOT(activateShade()) );
+    connect(inactiveButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateInactive()) );
+    connect(closeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateClose()) );
+    connect(minButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateMin()) );
+    connect(maxButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateMax()) );
+    connect(menuButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateMenu()) );
+    connect(helpButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateHelp()) );
+    connect(stickyButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateSticky()) );
+    connect(aboveButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateAbove()) );
+    connect(behindButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateBehind()) );
+    connect(shadeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateShade()) );
     
-    connect(inactiveColor, SIGNAL(colorChanged(TQColor)), inactiveButton, SLOT(setColor(TQColor)) );
-    connect(closeColor, SIGNAL(colorChanged(TQColor)), closeButton, SLOT(setColor(TQColor)) );
-    connect(minColor, SIGNAL(colorChanged(TQColor)), minButton, SLOT(setColor(TQColor)) );
-    connect(maxColor, SIGNAL(colorChanged(TQColor)), maxButton, SLOT(setColor(TQColor)) );
-    connect(menuColor, SIGNAL(colorChanged(TQColor)), menuButton, SLOT(setColor(TQColor)) );
-    connect(helpColor, SIGNAL(colorChanged(TQColor)), helpButton, SLOT(setColor(TQColor)) );
-    connect(stickyColor, SIGNAL(colorChanged(TQColor)), stickyButton, SLOT(setColor(TQColor)) );
-    connect(aboveColor, SIGNAL(colorChanged(TQColor)), aboveButton, SLOT(setColor(TQColor)) );
-    connect(behindColor, SIGNAL(colorChanged(TQColor)), behindButton, SLOT(setColor(TQColor)) );
-    connect(shadeColor, SIGNAL(colorChanged(TQColor)), shadeButton, SLOT(setColor(TQColor)) );
+    connect(inactiveColor, TQ_SIGNAL(colorChanged(TQColor)), inactiveButton, TQ_SLOT(setColor(TQColor)) );
+    connect(closeColor, TQ_SIGNAL(colorChanged(TQColor)), closeButton, TQ_SLOT(setColor(TQColor)) );
+    connect(minColor, TQ_SIGNAL(colorChanged(TQColor)), minButton, TQ_SLOT(setColor(TQColor)) );
+    connect(maxColor, TQ_SIGNAL(colorChanged(TQColor)), maxButton, TQ_SLOT(setColor(TQColor)) );
+    connect(menuColor, TQ_SIGNAL(colorChanged(TQColor)), menuButton, TQ_SLOT(setColor(TQColor)) );
+    connect(helpColor, TQ_SIGNAL(colorChanged(TQColor)), helpButton, TQ_SLOT(setColor(TQColor)) );
+    connect(stickyColor, TQ_SIGNAL(colorChanged(TQColor)), stickyButton, TQ_SLOT(setColor(TQColor)) );
+    connect(aboveColor, TQ_SIGNAL(colorChanged(TQColor)), aboveButton, TQ_SLOT(setColor(TQColor)) );
+    connect(behindColor, TQ_SIGNAL(colorChanged(TQColor)), behindButton, TQ_SLOT(setColor(TQColor)) );
+    connect(shadeColor, TQ_SIGNAL(colorChanged(TQColor)), shadeButton, TQ_SLOT(setColor(TQColor)) );
 
 }
 
