@@ -101,7 +101,7 @@ Applet::Applet( const TQString& configFile_P, TQWidget* parent_P ) : KPanelApple
    windowIndicator->setBackgroundOrigin(TQWidget::WidgetOrigin);
    windowIndicator->setLineWidth(0);
    windowList = new KWindowListMenu(windowIndicator);
-   connect(windowList, SIGNAL(aboutToShow()), this, SLOT(initPopup()));
+   connect(windowList, TQ_SIGNAL(aboutToShow()), this, TQ_SLOT(initPopup()));
    windowIndicator->insertItem( "KDE", windowList, 0);
    TQFont tmpFont = TDEGlobalSettings::menuFont();
    windowIndicator->setFont(tmpFont);
@@ -116,8 +116,8 @@ Applet::Applet( const TQString& configFile_P, TQWidget* parent_P ) : KPanelApple
    windowIndicator->setFixedWidth(windowIndicator->width() + 1);
    //==============
    // toolbarAppearanceChanged(int) is sent when changing macstyle
-   connect( kapp, SIGNAL( toolbarAppearanceChanged( int )), this, SLOT( readSettings()));
-   connect( kapp, SIGNAL( tdedisplayFontChanged()), this, SLOT( fontChanged()));
+   connect( kapp, TQ_SIGNAL( toolbarAppearanceChanged( int )), this, TQ_SLOT( readSettings()));
+   connect( kapp, TQ_SIGNAL( tdedisplayFontChanged()), this, TQ_SLOT( fontChanged()));
    claimSelection();
    readSettings();
    updateTopEdgeOffset();
@@ -167,7 +167,7 @@ void Applet::moveMenu()
    if (!wannaMove)
       return;
    active_menu->move( active_menu->x() + menuDX,  active_menu->y());
-   TQTimer::singleShot(100, this, SLOT(moveMenu()));
+   TQTimer::singleShot(100, this, TQ_SLOT(moveMenu()));
 }
 
 bool Applet::eventFilter(TQObject *o, TQEvent *ev)
@@ -181,14 +181,14 @@ bool Applet::eventFilter(TQObject *o, TQEvent *ev)
                menuDX = -5;
                wannaMove = true;
                active_menu->move( active_menu->x() - 5,  active_menu->y());
-               TQTimer::singleShot(200, this, SLOT(moveMenu()));
+               TQTimer::singleShot(200, this, TQ_SLOT(moveMenu()));
             }
             else
             {
                menuDX = 5;
                wannaMove = true;
                active_menu->move( active_menu->x() + 5,  active_menu->y());
-               TQTimer::singleShot(200, this, SLOT(moveMenu()));
+               TQTimer::singleShot(200, this, TQ_SLOT(moveMenu()));
             }
             return false;
          }
@@ -510,10 +510,10 @@ void Applet::claimSelection()
    {
       delete selection_watcher;
       selection_watcher = NULL;
-      connect( selection, SIGNAL( lostOwnership()), SLOT( lostSelection()));
+      connect( selection, TQ_SIGNAL( lostOwnership()), TQ_SLOT( lostSelection()));
       module = new KWinModule;
-      connect( module, SIGNAL( windowAdded( WId )), this, SLOT( windowAdded( WId )));
-      connect( module, SIGNAL( activeWindowChanged( WId )), this, SLOT( activeWindowChanged( WId )));
+      connect( module, TQ_SIGNAL( windowAdded( WId )), this, TQ_SLOT( windowAdded( WId )));
+      connect( module, TQ_SIGNAL( activeWindowChanged( WId )), this, TQ_SLOT( activeWindowChanged( WId )));
       TQValueList< WId > windows = module->windows();
       for( TQValueList< WId >::ConstIterator it = windows.begin(); it != windows.end(); ++it )
       windowAdded( *it );
@@ -537,7 +537,7 @@ void Applet::lostSelection()
     if( selection_watcher == NULL )
         {
         selection_watcher = new TDESelectionWatcher( makeSelectionAtom(), DefaultScreen( tqt_xdisplay()));
-        connect( selection_watcher, SIGNAL( lostOwner()), this, SLOT( claimSelection()));
+        connect( selection_watcher, TQ_SIGNAL( lostOwner()), this, TQ_SLOT( claimSelection()));
         }
     delete module;
     module = NULL;
