@@ -60,8 +60,8 @@ UserManager::UserManager(const TQString& configFile, Type type, int actions, TQW
    // sessions
    sessionPopup = new TQPopupMenu(this);
    menu->insertItem ( getenv("USER"), sessionPopup, 0);
-   connect( sessionPopup, SIGNAL(aboutToShow()), SLOT(slotPopulateSessions()) );
-   connect( sessionPopup, SIGNAL(activated(int)), SLOT(slotSessionActivated(int)) );
+   connect( sessionPopup, TQ_SIGNAL(aboutToShow()), TQ_SLOT(slotPopulateSessions()) );
+   connect( sessionPopup, TQ_SIGNAL(activated(int)), TQ_SLOT(slotSessionActivated(int)) );
    
    // languages
    langPopup = new TQPopupMenu(this);
@@ -74,9 +74,9 @@ UserManager::UserManager(const TQString& configFile, Type type, int actions, TQW
 //    langLabel->setPixmap(_ICONSET_(flag).pixmap());
    
    menu->insertItem ( '[' + langList[0].section('_',0,0) + ']', langPopup, 1 );
-   menu->connectItem ( 1, this, SLOT(slotPopulateLanguages()) );
-   connect( langPopup, SIGNAL(aboutToShow()), SLOT(slotPopulateLanguages()) );
-   connect( langPopup, SIGNAL(activated(int)), SLOT(slotLanguageActivated(int)) );
+   menu->connectItem ( 1, this, TQ_SLOT(slotPopulateLanguages()) );
+   connect( langPopup, TQ_SIGNAL(aboutToShow()), TQ_SLOT(slotPopulateLanguages()) );
+   connect( langPopup, TQ_SIGNAL(activated(int)), TQ_SLOT(slotLanguageActivated(int)) );
    
    menu->adjustSize();
    
