@@ -74,18 +74,18 @@ starter::starter(const TQString& configFile, Type type, int actions, TQWidget *p
    startMenu = new StartMenu(_iconSize, this, TQt::WType_Popup);
    shortcutList = startMenu->shortcutList;
    configDialog->categoryList->insertStringList(startMenu->categories());
-   connect (startMenu, SIGNAL(aboutToHide()), this, SLOT(unblockPopupDelayed()));
-   connect(configDialog->useKTTS, SIGNAL(toggled( bool )), startMenu, SLOT(toggleKTTS(bool)));
+   connect (startMenu, TQ_SIGNAL(aboutToHide()), this, TQ_SLOT(unblockPopupDelayed()));
+   connect(configDialog->useKTTS, TQ_SIGNAL(toggled( bool )), startMenu, TQ_SLOT(toggleKTTS(bool)));
    
    //---
-   connect(configDialog->categoryList, SIGNAL(highlighted(int)), this, SLOT(activateShortcutButton(int)));
-   connect(configDialog->buttonShortcut, SIGNAL(capturedShortcut (const TDEShortcut &)), this, SLOT(addShortcut(const TDEShortcut &)));
-   connect(configDialog->categoryList, SIGNAL(highlighted ( const TQString & )), this, SLOT(updateShortcutButton(const TQString &)));
-   connect(configDialog->buttonOk, SIGNAL(clicked()), this, SLOT(updateSettings()));
+   connect(configDialog->categoryList, TQ_SIGNAL(highlighted(int)), this, TQ_SLOT(activateShortcutButton(int)));
+   connect(configDialog->buttonShortcut, TQ_SIGNAL(capturedShortcut (const TDEShortcut &)), this, TQ_SLOT(addShortcut(const TDEShortcut &)));
+   connect(configDialog->categoryList, TQ_SIGNAL(highlighted ( const TQString & )), this, TQ_SLOT(updateShortcutButton(const TQString &)));
+   connect(configDialog->buttonOk, TQ_SIGNAL(clicked()), this, TQ_SLOT(updateSettings()));
    StarterHelp *helpDialog = new StarterHelp(configDialog);
-   connect(configDialog->buttonHelp, SIGNAL(clicked()), helpDialog, SLOT(show()));
+   connect(configDialog->buttonHelp, TQ_SIGNAL(clicked()), helpDialog, TQ_SLOT(show()));
    //-----
-   configPopup->insertItem(i18n("Configure the Startmenu"), configDialog, SLOT(show()));
+   configPopup->insertItem(i18n("Configure the Startmenu"), configDialog, TQ_SLOT(show()));
    configDialog->BaseURL->setFilter( "*.png" );
    configDialog->HoverURL->setFilter( "*.png" );
    configDialog->DownURL->setFilter( "*.png" );
@@ -302,7 +302,7 @@ int starter::heightForWidth(int width) const
 void starter::unblockPopupDelayed()
 {
    popupBlocked = true;
-   TQTimer::singleShot ( 50, this, SLOT(unblockPopup()) );
+   TQTimer::singleShot ( 50, this, TQ_SLOT(unblockPopup()) );
 }
 
 void starter::unblockPopup()
